# Class: puppet
#
# This class updates puppet
#

class puppet {

  if $::operatingsystem in ['Ubuntu', 'Debian'] {

    exec { "puppet-wget-${::lsbdistcodename}":
      command => "wget https://apt.puppetlabs.com/puppetlabs-release-${::lsbdistcodename}.deb",
      path    => '/usr/bin:/bin:/usr/sbin:/sbin'
    }

    exec { "puppet-dpkg-${::lsbdistcodename}":
      command => "dpkg -i puppetlabs-release-${::lsbdistcodename}.deb",
      path    => '/usr/bin:/bin:/usr/sbin:/sbin',
      require => Exec["puppet-wget-${::lsbdistcodename}"]
    }

    exec { 'puppet-apt-get-update':
      command => 'apt-get update -y',
      path    => '/usr/bin:/bin:/usr/sbin:/sbin',
      require => Exec["puppet-dpkg-${::lsbdistcodename}"]
    }

    exec { 'puppet-apt-get-install':
      command => 'apt-get install puppet -y',
      path    => '/usr/bin:/bin:/usr/sbin:/sbin',
      require => Exec['puppet-apt-get-update']
    }

  }  elsif $::operatingsystem in ['CentOS'] {

    exec { "puppet-rpm-${::operatingsystemmajrelease}":
      command => "rpm -ivh http://yum.puppetlabs.com/puppetlabs-release-el-${::operatingsystemmajrelease}.noarch.rpm",
      path    => '/usr/bin:/bin:/usr/sbin:/sbin',
      unless  => "rpm -qa | grep puppetlabs-release-${::operatingsystemmajrelease}"
    }

    exec { 'puppet-yum-install':
      command => 'yum install puppet -y',
      path    => '/usr/bin:/bin:/usr/sbin:/sbin',
      require => Exec["puppet-rpm-${::operatingsystemmajrelease}"]
    }

  }  elsif $::operatingsystem in ['Fedora'] {

    exec { "puppet-rpm-${::operatingsystemrelease}":
      command => "rpm -ivh http://yum.puppetlabs.com/puppetlabs-release-fedora-${::operatingsystemrelease}.noarch.rpm",
      path    => '/usr/bin:/bin:/usr/sbin:/sbin',
      unless  => "rpm -qa | grep puppetlabs-release-${::operatingsystemrelease}"
    }

    exec { 'puppet-rpm-install':
      command => 'yum install puppet -y',
      path    => '/usr/bin:/bin:/usr/sbin:/sbin',
      require => Exec["puppet-rpm-${::operatingsystemrelease}"]
    }

  } else {
    fail('Platform not supported.')
  }

}